@@ -1,4 +1,4 @@
-__version__ = "6.1.21"
+__version__ = "6.1.26"
 
 from zuper_commons.logs import ZLogger
 
@@ -23,3 +23,6 @@ from .get_versions import *
 from .misc import *
 from .docker_building import *
 from .updating_versions import *
+from .docker_logging_in import *
+from .credentials import *
+from .caching import *
